﻿namespace U2UConsult.WinRT.EnumerationSlider.ViewModels
{
    using Enumerations;

    public class MainPageViewModel : BindableBase
    {
        private Sizes coffeeSize = Sizes.Grande;

        /// <summary>
        /// Coffee Size property as it comes directly from the Mvvm Model.
        /// </summary>
        public Sizes CoffeeSize
        {
            get { return coffeeSize; }
            set
            {
                this.SetProperty(ref this.coffeeSize, value);
                this.OnPropertyChanged("CoffeeString");
            }
        }

        /// <summary>
        /// Wrapper around the CoffeeSize property to make it bindable.
        /// Works around "Error: Cannot save value from target back to source."
        /// </summary>
        /// <remarks>
        /// No that's not complicated. This is exactly what viewmodels are supposed to do.
        /// </remarks>
        public string CoffeeString
        {
            get { return this.coffeeSize.ToString(); }
            set { this.CoffeeSize = (Sizes)System.Enum.Parse(typeof(Sizes), value); }
        }

        private Temperatures temperature;

        public Temperatures Temperature
        {
            get { return this.temperature; }
            set
            {
                this.SetProperty(ref this.temperature, value);
                this.OnPropertyChanged("TemperatureString");
            }
        }

        public string TemperatureString
        {
            get { return this.temperature.ToString(); }
            set { this.Temperature = (Temperatures)System.Enum.Parse(typeof(Temperatures), value); }
        }
    }
}

